==> v1.0.0.20190930_beta.tar.gz: fastadmin/application/admin/lang/zh-cn.php <==
<?php

return [
    'User id'                                               => '会员ID',
    'Username'                                              => '用户名',
    'Nickname'                                              => '昵称',
    'Password'                                              => '密码',
    'Sign up'                                               => '注 册',
    'Sign in'                                               => '登 录',
    'Sign out'                                              => '注 销',
    'Keep login'                                            => '保持会话',
    'Guest'                                                 => '游客',
    'Welcome'                                               => '%s，你好！',
    'View'                                                  => '查看',
    'Add'                                                   => '添加',
    'Edit'                                                  => '编辑',
    'Del'                                                   => '删除',
    'Delete'                                                => '删除',
    'Import'                                                => '导入',
    'Export'                                                => '导出',
    'All'                                                   => '全部',
    'Detail'                                                => '详情',
    'Multi'                                                 => '批量更新',
    'Setting'                                               => '配置',
    'Move'                                                  => '移动',
    'Name'                                                  => '名称',
    'Status'                                                => '状态',
    'Weigh'                                                 => '权重',
    'Operate'                                               => '操作',
    'Warning'                                               => '温馨提示',
    'Default'                                               => '默认',
    'Article'                                               => '文章',
    'Page'                                                  => '单页',
    'OK'                                                    => '确定',
    'Apply'                                                 => '应用',
    'Cancel'                                                => '取消',
    'Clear'                                                 => '清空',
    'Custom Range'                                          => '自定义',
    'Today'                                                 => '今天',
    'Yesterday'                                             => '昨天',
    'Last 7 days'                                           => '最近7天',
    'Last 30 days'                                          => '最近30天',
    'Last month'                                            => '上月',
    'This month'                                            => '本月',
    'Loading'                                               => '加载中',
    'Money'                                                 => '余额',
    'Score'                                                 => '积分',
    'More'                                                  => '更多',
    'Yes'                                                   => '是',
    'No'                                                    => '否',
    'Normal'                                                => '正常',
    'Hidden'                                                => '隐藏',
    'Locked'                                                => '锁定',
    'Submit'                                                => '提交',
    'Reset'                                                 => '重置',
    'Execute'                                               => '执行',
    'Close'                                                 => '关闭',
    'Choose'                                                => '选择',
    'Search'                                                => '搜索',
    'Refresh'                                               => '刷新',
    'Install'                                               => '安装',
    'Uninstall'                                             => '卸载',
    'First'                                                 => '首页',
    'Previous'                                              => '上一页',
    'Next'                                                  => '下一页',
    'Last'                                                  => '末页',
    'None'                                                  => '无',
    'Home'                                                  => '主页',
    'Online'                                                => '在线',
    'Login'                                                 => '登录',
    'Logout'                                                => '注销',
    'Profile'                                               => '个人资料',
    'Index'                                                 => '首页',
    'Hot'                                                   => '热门',
    'Recommend'                                             => '推荐',
    'Upload'                                                => '上传',
    'Uploading'                                             => '上传中',
    'Code'                                                  => '编号',
    'Message'                                               => '内容',
    'Line'                                                  => '行号',
    'File'                                                  => '文件',
    'Menu'                                                  => '菜单',
    'Type'                                                  => '类型',
    'Title'                                                 => '标题',
    'Content'                                               => '内容',
    'Append'                                                => '追加',
    'Select'                                                => '选择',
    'Memo'                                                  => '备注',
    'Parent'                                                => '父级',
    'Params'                                                => '参数',
    'Permission'                                            => '权限',
    'Check all'                                             => '选中全部',
    'Expand all'                                            => '展开全部',
    'Begin time'                                            => '开始时间',
    'End time'                                              => '结束时间',
    'Create time'                                           => '创建时间',
    'Update time'                                           => '更新时间',
    'Flag'                                                  => '标志',
    'Drag to sort'                                          => '拖动进行排序',
    'Redirect now'                                          => '立即跳转',
    'Key'                                                   => '键',
    'Value'                                                 => '值',
    'Common search'                                         => '普通搜索',
    'Search %s'                                             => '搜索 %s',
    'View %s'                                               => '查看 %s',
    '%d second%s ago'                                       => '%d秒前',
    '%d minute%s ago'                                       => '%d分钟前',
    '%d hour%s ago'                                         => '%d小时前',
    '%d day%s ago'                                          => '%d天前',
    '%d week%s ago'                                         => '%d周前',
    '%d month%s ago'                                        => '%d月前',
    '%d year%s ago'                                         => '%d年前',
    'Set to normal'                                         => '设为正常',
    'Set to hidden'                                         => '设为隐藏',
    'Recycle bin'                                           => '回收站',
    'Restore'                                               => '还原',
    'Restore all'                                           => '还原全部',
    'Destroy'                                               => '销毁',
    'Destroy all'                                           => '清空回收站',
    'Nothing need restore'                                  => '没有需要还原的数据',
    //提示
    'Go back'                                               => '返回首页',
    'Jump now'                                              => '立即跳转',
    'Click to search %s'                                    => '点击搜索 %s',
    'Click to toggle'                                       => '点击切换',
    'Operation completed'                                   => '操作成功!',
    'Operation failed'                                      => '操作失败!',
    'Unknown data format'                                   => '未知的数据格式!',
    'Network error'                                         => '网络错误!',
    'Invalid parameters'                                    => '未知参数',
    'No results were found'                                 => '记录未找到',
    'No rows were inserted'                                 => '未插入任何行',
    'No rows were deleted'                                  => '未删除任何行',
    'No rows were updated'                                  => '未更新任何行',
    'Parameter %s can not be empty'                         => '参数%s不能为空',
    'Are you sure you want to delete the %s selected item?' => '确定删除选中的 %s 项?',
    'Are you sure you want to delete this item?'            => '确定删除此项?',
    'Are you sure you want to delete or turncate?'          => '确定删除或清空?',
    'Are you sure you want to truncate?'                    => '确定清空?',
    'Token verification error'                              => 'Token验证错误！',
    'You have no permission'                                => '你没有权限访问',
    'Please enter your username'                            => '请输入你的用户名',
    'Please enter your password'                            => '请输入你的密码',
    'Please login first'                                    => '请登录后操作',
    'You can upload up to %d file%s'                        => '你最多还可以上传%d个文件',
    'You can choose up to %d file%s'                        => '你最多还可以选择%d个文件',
    'An unexpected error occurred'                          => '发生了一个意外错误,程序猿正在紧急处理中',
    'This page will be re-directed in %s seconds'           => '页面将在 %s 秒后自动跳转',
    //菜单
    'Dashboard'                                             => '控制台',
    'General'                                               => '常规管理',
    'Category'                                              => '分类管理',
    'Addon'                                                 => '插件管理',
    'Auth'                                                  => '权限管理',
    'Config'                                                => '系统配置',
    'Attachment'                                            => '附件管理',
    'Admin'                                                 => '管理员管理',
    'Admin log'                                             => '管理员日志',
    'Group'                                                 => '角色组',
    'Rule'                                                  => '菜单规则',
    'User'                                                  => '会员管理',
    'User group'                                            => '会员分组',
    'User rule'                                             => '会员规则',
    'Select attachment'                                     => '选择附件',
    'Update profile'                                        => '更新个人信息',
    'Local install'                                         => '本地安装',
    'Update state'                                          => '禁用启用',
    'Admin group'                                           => '超级管理组',
    'Second group'                                          => '二级管理组',
    'Third group'                                           => '三级管理组',
    'Second group 2'                                        => '二级管理组2',
    'Third group 2'                                         => '三级管理组2',
    'Dashboard tips'                                        => '用于展示当前系统中的统计数据、统计报表及重要实时数据',
    'Config tips'                                           => '可以在此增改系统的变量和分组,也可以自定义分组和变量,如果需要删除请从数据库中删除',
    'Category tips'                                         => '用于统一管理网站的所有分类,分类可进行无限级分类,分类类型请在常规管理->系统配置->字典配置中添加',
    'Attachment tips'                                       => '主要用于管理上传到服务器或第三方存储的数据',
    'Addon tips'                                            => '可在线安装、卸载、禁用、启用插件，同时支持添加本地插件。FastAdmin已上线插件商店 ，你可以发布你的免费或付费插件：<a href="https://www.fastadmin.net/store.html" target="_blank">https://www.fastadmin.net/store.html</a>',
    'Admin tips'                                            => '一个管理员可以有多个角色组,左侧的菜单根据管理员所拥有的权限进行生成',
    'Admin log tips'                                        => '管理员可以查看自己所拥有的权限的管理员日志',
    'Group tips'                                            => '角色组可以有多个,角色有上下级层级关系,如果子角色有角色组和管理员的权限则可以派生属于自己组别的下级角色组或管理员',
    'Rule tips'                                             => '规则通常对应一个控制器的方法,同时左侧的菜单栏数据也从规则中体现,通常建议通过命令行进行生成规则节点',
];

==> v1.0.0.20201001_beta.tar.gz: fastadmin/application/admin/lang/zh-cn.php <==
<?php

return [
    'User id'                                               => '会员ID',
    'Username'                                              => '用户名',
    'Nickname'                                              => '昵称',
    'Password'                                              => '密码',
    'Sign up'                                               => '注 册',
    'Sign in'                                               => '登 录',
    'Sign out'                                              => '退 出',
    'Keep login'                                            => '保持会话',
    'Guest'                                                 => '游客',
    'Welcome'                                               => '%s，你好！',
    'View'                                                  => '查看',
    'Add'                                                   => '添加',
    'Edit'                                                  => '编辑',
    'Del'                                                   => '删除',
    'Delete'                                                => '删除',
    'Import'                                                => '导入',
    'Export'                                                => '导出',
    'All'                                                   => '全部',
    'Detail'                                                => '详情',
    'Multi'                                                 => '批量更新',
    'Setting'                                               => '配置',
    'Move'                                                  => '移动',
    'Name'                                                  => '名称',
    'Status'                                                => '状态',
    'Weigh'                                                 => '权重',
    'Operate'                                               => '操作',
    'Warning'                                               => '温馨提示',
    'Default'                                               => '默认',
    'Article'                                               => '文章',
    'Page'                                                  => '单页',
    'OK'                                                    => '确定',
    'Apply'                                                 => '应用',
    'Cancel'                                                => '取消',
    'Clear'                                                 => '清空',
    'Custom Range'                                          => '自定义',
    'Today'                                                 => '今天',
    'Yesterday'                                             => '昨天',
    'Last 7 days'                                           => '最近7天',
    'Last 30 days'                                          => '最近30天',
    'Last month'                                            => '上月',
    'This month'                                            => '本月',
    'Loading'                                               => '加载中',
    'Money'                                                 => '余额',
    'Score'                                                 => '积分',
    'More'                                                  => '更多',
    'Yes'                                                   => '是',
    'No'                                                    => '否',
    'Normal'                                                => '正常',
    'Hidden'                                                => '隐藏',
    'Locked'                                                => '锁定',
    'Submit'                                                => '提交',
    'Reset'                                                 => '重置',
    'Execute'                                               => '执行',
    'Close'                                                 => '关闭',
    'Choose'                                                => '选择',
    'Go'                                                    => '跳转',
    'Search'                                                => '搜索',
    'Refresh'                                               => '刷新',
    'Install'                                               => '安装',
    'Uninstall'                                             => '卸载',
    'First'                                                 => '首页',
    'Previous'                                              => '上一页',
    'Next'                                                  => '下一页',
    'Last'                                                  => '末页',
    'None'                                                  => '无',
    'Home'                                                  => '主页',
    'Online'                                                => '在线',
    'Login'                                                 => '登录',
    'Logout'                                                => '退出',
    'Profile'                                               => '个人资料',
    'Index'                                                 => '首页',
    'Hot'                                                   => '热门',
    'Recommend'                                             => '推荐',
    'Upload'                                                => '上传',
    'Uploading'                                             => '上传中',
    'Code'                                                  => '编号',
    'Message'                                               => '内容',
    'Line'                                                  => '行号',
    'File'                                                  => '文件',
    'Menu'                                                  => '菜单',
    'Type'                                                  => '类型',
    'Title'                                                 => '标题',
    'Content'                                               => '内容',
    'Append'                                                => '追加',
    'Select'                                                => '选择',
    'Memo'                                                  => '备注',
    'Parent'                                                => '父级',
    'Params'                                                => '参数',
    'Permission'                                            => '权限',
    'Check all'                                             => '选中全部',
    'Expand all'                                            => '展开全部',
    'Begin time'                                            => '开始时间',
    'End time'                                              => '结束时间',
    'Create time'                                           => '创建时间',
    'Update time'                                           => '更新时间',
    'Createtime'                                            => '创建时间',
    'Updatetime'                                            => '更新时间',
    'Deletetime'                                            => '删除时间',
    'Flag'                                                  => '标志',
    'Drag to sort'                                          => '拖动进行排序',
    'Redirect now'                                          => '立即跳转',
    'Key'                                                   => '键',
    'Value'                                                 => '值',
    'Common search'                                         => '普通搜索',
    'Search %s'                                             => '搜索 %s',
    'View %s'                                               => '查看 %s',
    '%d second%s ago'                                       => '%d秒前',
    '%d minute%s ago'                                       => '%d分钟前',
    '%d hour%s ago'                                         => '%d小时前',
    '%d day%s ago'                                          => '%d天前',
    '%d week%s ago'                                         => '%d周前',
    '%d month%s ago'                                        => '%d月前',
    '%d year%s ago'                                         => '%d年前',
    'Set to normal'                                         => '设为正常',
    'Set to hidden'                                         => '设为隐藏',
    'Recycle bin'                                           => '回收站',
    'Restore'                                               => '还原',
    'Restore all'                                           => '还原全部',
    'Destroy'                                               => '销毁',
    'Destroy all'                                           => '清空回收站',
    'Nothing need restore'                                  => '没有需要还原的数据',
    //提示
    'Go back'                                               => '返回首页',
    'Jump now'                                              => '立即跳转',
    'Click to search %s'                                    => '点击搜索 %s',
    'Click to toggle'                                       => '点击切换',
    'Operation completed'                                   => '操作成功!',
    'Operation failed'                                      => '操作失败!',
    'Unknown data format'                                   => '未知的数据格式!',
    'Network error'                                         => '网络错误!',
    'Invalid parameters'                                    => '未知参数',
    'No results were found'                                 => '记录未找到',
    'No rows were inserted'                                 => '未插入任何行',
    'No rows were deleted'                                  => '未删除任何行',
    'No rows were updated'                                  => '未更新任何行',
    'Parameter %s can not be empty'                         => '参数%s不能为空',
    'Are you sure you want to delete the %s selected item?' => '确定删除选中的 %s 项?',
    'Are you sure you want to delete this item?'            => '确定删除此项?',
    'Are you sure you want to delete or turncate?'          => '确定删除或清空?',
    'Are you sure you want to truncate?'                    => '确定清空?',
    'Token verification error'                              => 'Token验证错误！',
    'You have no permission'                                => '你没有权限访问',
    'Please enter your username'                            => '请输入你的用户名',
    'Please enter your password'                            => '请输入你的密码',
    'Please login first'                                    => '请登录后操作',
    'Uploaded successful'                                   => '上传成功',
    'You can upload up to %d file%s'                        => '你最多还可以上传%d个文件',
    'You can choose up to %d file%s'                        => '你最多还可以选择%d个文件',
    'Chunk file write error'                                => '分片写入失败',
    'Chunk file info error'                                 => '分片文件错误',
    'Chunk file merge error'                                => '分片合并错误',
    'Chunk file disabled'                                   => '未开启分片上传功能',
    'Cancel upload'                                         => '取消上传',
    'Upload canceled'                                       => '上传已取消',
    'No file upload or server upload limit exceeded'        => '未上传文件或超出服务器上传限制',
    'Uploaded file format is limited'                       => '上传文件格式受限制',
    'Uploaded file is not a valid image'                    => '上传文件不是有效的图片文件',
    'Are you sure you want to cancel this upload?'          => '确定取消上传？',
    'Remove file'                                           => '移除文件',
    'You can only upload a maximum of %s files'             => '你最多允许上传 %s 个文件',
    'You can\'t upload files of this type'                  => '不允许上传的文件类型',
    'Server responded with %s code'                         => '服务端响应(Code:%s)',
    'File is too big (%sMiB), Max filesize: %sMiB'          => '当前上传(%sM)，最大允许上传文件大小:%sM',
    'An unexpected error occurred'                          => '发生了一个意外错误,程序猿正在紧急处理中',
    'This page will be re-directed in %s seconds'           => '页面将在 %s 秒后自动跳转',
    'Click to uncheck all'                                  => '点击取消全部',
    'Multiple selection mode: %s checked'                   => '跨页选择模式，已选 %s 项',
    //菜单
    'Dashboard'                                             => '控制台',
    'General'                                               => '常规管理',
    'Category'                                              => '分类管理',
    'Addon'                                                 => '插件管理',
    'Auth'                                                  => '权限管理',
    'Config'                                                => '系统配置',
    'Attachment'                                            => '附件管理',
    'Admin'                                                 => '管理员管理',
    'Admin log'                                             => '管理员日志',
    'Group'                                                 => '角色组',
    'Rule'                                                  => '菜单规则',
    'User'                                                  => '会员管理',
    'User group'                                            => '会员分组',
    'User rule'                                             => '会员规则',
    'Select attachment'                                     => '选择附件',
    'Update profile'                                        => '更新个人信息',
    'Local install'                                         => '本地安装',
    'Update state'                                          => '禁用启用',
    'Admin group'                                           => '超级管理组',
    'Second group'                                          => '二级管理组',
    'Third group'                                           => '三级管理组',
    'Second group 2'                                        => '二级管理组2',
    'Third group 2'                                         => '三级管理组2',
    'Dashboard tips'                                        => '用于展示当前系统中的统计数据、统计报表及重要实时数据',
    'Config tips'                                           => '可以在此增改系统的变量和分组,也可以自定义分组和变量',
    'Category tips'                                         => '用于统一管理网站的所有分类,分类可进行无限级分类,分类类型请在常规管理->系统配置->字典配置中添加',
    'Attachment tips'                                       => '主要用于管理上传到服务器或第三方存储的数据',
    'Addon tips'                                            => '可在线安装、卸载、禁用、启用插件，同时支持添加本地插件。',
    'Admin tips'                                            => '一个管理员可以有多个角色组,左侧的菜单根据管理员所拥有的权限进行生成',
    'Admin log tips'                                        => '管理员可以查看自己所拥有的权限的管理员日志',
    'Group tips'                                            => '角色组可以有多个,角色有上下级层级关系,如果子角色有角色组和管理员的权限则可以派生属于自己组别的下级角色组或管理员',
    'Rule tips'                                             => '规则通常对应一个控制器的方法,同时左侧的菜单栏数据也从规则中体现,通常建议通过命令行进行生成规则节点',
    'Access is allowed only to the super management group'  => '仅超级管理组能访问',
    'Local addon'                                           => '本地插件',
    // 前台菜单
    'Frontend'                                              => '前台',
    'API Interface'                                         => 'API接口',
    'User Module'                                           => '会员模块',
    'Register'                                              => '注册',
    'User Center'                                           => '会员中心',
];
